[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)

# Lumiere 
Implementation of the text to video model LUMIERE from the paper: "A Space-Time Diffusion Model for Video Generation" by Google Research. I will mostly be implementing the modules from the diagram a and b in figure 4

## Install
`pip install lumiere`


## Usage
```

```


# License
MIT
